# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetProviderIntegrationAuthorizationResult',
    'AwaitableGetProviderIntegrationAuthorizationResult',
    'get_provider_integration_authorization',
    'get_provider_integration_authorization_output',
]

@pulumi.output_type
class GetProviderIntegrationAuthorizationResult:
    """
    A collection of values returned by getProviderIntegrationAuthorization.
    """
    def __init__(__self__, azures=None, environment=None, gcps=None, id=None, provider_integration_id=None):
        if azures and not isinstance(azures, list):
            raise TypeError("Expected argument 'azures' to be a list")
        pulumi.set(__self__, "azures", azures)
        if environment and not isinstance(environment, dict):
            raise TypeError("Expected argument 'environment' to be a dict")
        pulumi.set(__self__, "environment", environment)
        if gcps and not isinstance(gcps, list):
            raise TypeError("Expected argument 'gcps' to be a list")
        pulumi.set(__self__, "gcps", gcps)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if provider_integration_id and not isinstance(provider_integration_id, str):
            raise TypeError("Expected argument 'provider_integration_id' to be a str")
        pulumi.set(__self__, "provider_integration_id", provider_integration_id)

    @_builtins.property
    @pulumi.getter
    def azures(self) -> Sequence['outputs.GetProviderIntegrationAuthorizationAzureResult']:
        """
        (Optional Configuration Block) Azure-specific configuration details. Present for Azure integrations. It supports the following:
        """
        return pulumi.get(self, "azures")

    @_builtins.property
    @pulumi.getter
    def environment(self) -> 'outputs.GetProviderIntegrationAuthorizationEnvironmentResult':
        """
        (Required Configuration Block) supports the following:
        """
        return pulumi.get(self, "environment")

    @_builtins.property
    @pulumi.getter
    def gcps(self) -> Sequence['outputs.GetProviderIntegrationAuthorizationGcpResult']:
        """
        (Optional Configuration Block) GCP-specific configuration details. Present for GCP integrations. It supports the following:
        """
        return pulumi.get(self, "gcps")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        (Required String) The ID of the Environment that the Provider Integration belongs to, for example, `env-abc123`.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="providerIntegrationId")
    def provider_integration_id(self) -> _builtins.str:
        """
        (Required String) The ID of the provider integration.
        """
        return pulumi.get(self, "provider_integration_id")


class AwaitableGetProviderIntegrationAuthorizationResult(GetProviderIntegrationAuthorizationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProviderIntegrationAuthorizationResult(
            azures=self.azures,
            environment=self.environment,
            gcps=self.gcps,
            id=self.id,
            provider_integration_id=self.provider_integration_id)


def get_provider_integration_authorization(environment: Optional[Union['GetProviderIntegrationAuthorizationEnvironmentArgs', 'GetProviderIntegrationAuthorizationEnvironmentArgsDict']] = None,
                                           id: Optional[_builtins.str] = None,
                                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProviderIntegrationAuthorizationResult:
    """
    Use this data source to access information about an existing resource.

    :param Union['GetProviderIntegrationAuthorizationEnvironmentArgs', 'GetProviderIntegrationAuthorizationEnvironmentArgsDict'] environment: (Required Configuration Block) supports the following:
    :param _builtins.str id: The ID of the Provider Integration Authorization, for example, `cspi-4xg0q`.
    """
    __args__ = dict()
    __args__['environment'] = environment
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('confluentcloud:index/getProviderIntegrationAuthorization:getProviderIntegrationAuthorization', __args__, opts=opts, typ=GetProviderIntegrationAuthorizationResult).value

    return AwaitableGetProviderIntegrationAuthorizationResult(
        azures=pulumi.get(__ret__, 'azures'),
        environment=pulumi.get(__ret__, 'environment'),
        gcps=pulumi.get(__ret__, 'gcps'),
        id=pulumi.get(__ret__, 'id'),
        provider_integration_id=pulumi.get(__ret__, 'provider_integration_id'))
def get_provider_integration_authorization_output(environment: Optional[pulumi.Input[Union['GetProviderIntegrationAuthorizationEnvironmentArgs', 'GetProviderIntegrationAuthorizationEnvironmentArgsDict']]] = None,
                                                  id: Optional[pulumi.Input[_builtins.str]] = None,
                                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProviderIntegrationAuthorizationResult]:
    """
    Use this data source to access information about an existing resource.

    :param Union['GetProviderIntegrationAuthorizationEnvironmentArgs', 'GetProviderIntegrationAuthorizationEnvironmentArgsDict'] environment: (Required Configuration Block) supports the following:
    :param _builtins.str id: The ID of the Provider Integration Authorization, for example, `cspi-4xg0q`.
    """
    __args__ = dict()
    __args__['environment'] = environment
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('confluentcloud:index/getProviderIntegrationAuthorization:getProviderIntegrationAuthorization', __args__, opts=opts, typ=GetProviderIntegrationAuthorizationResult)
    return __ret__.apply(lambda __response__: GetProviderIntegrationAuthorizationResult(
        azures=pulumi.get(__response__, 'azures'),
        environment=pulumi.get(__response__, 'environment'),
        gcps=pulumi.get(__response__, 'gcps'),
        id=pulumi.get(__response__, 'id'),
        provider_integration_id=pulumi.get(__response__, 'provider_integration_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['PluginArgs', 'Plugin']

@pulumi.input_type
class PluginArgs:
    def __init__(__self__, *,
                 cloud: pulumi.Input[_builtins.str],
                 display_name: pulumi.Input[_builtins.str],
                 environment: pulumi.Input['PluginEnvironmentArgs'],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 runtime_language: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Plugin resource.
        :param pulumi.Input[_builtins.str] cloud: Cloud provider where the Custom Connector Plugin archive is uploaded. Accepted values are: `AWS`, `AZURE`, `GCP`.
        :param pulumi.Input[_builtins.str] display_name: The name of the Plugin.
        :param pulumi.Input['PluginEnvironmentArgs'] environment: Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        :param pulumi.Input[_builtins.str] description: The description of the Plugin.
        :param pulumi.Input[_builtins.str] runtime_language: (Optional String) Runtime language of the plugin.
        """
        pulumi.set(__self__, "cloud", cloud)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "environment", environment)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if runtime_language is not None:
            pulumi.set(__self__, "runtime_language", runtime_language)

    @_builtins.property
    @pulumi.getter
    def cloud(self) -> pulumi.Input[_builtins.str]:
        """
        Cloud provider where the Custom Connector Plugin archive is uploaded. Accepted values are: `AWS`, `AZURE`, `GCP`.
        """
        return pulumi.get(self, "cloud")

    @cloud.setter
    def cloud(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "cloud", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[_builtins.str]:
        """
        The name of the Plugin.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter
    def environment(self) -> pulumi.Input['PluginEnvironmentArgs']:
        """
        Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: pulumi.Input['PluginEnvironmentArgs']):
        pulumi.set(self, "environment", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the Plugin.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="runtimeLanguage")
    def runtime_language(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Optional String) Runtime language of the plugin.
        """
        return pulumi.get(self, "runtime_language")

    @runtime_language.setter
    def runtime_language(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "runtime_language", value)


@pulumi.input_type
class _PluginState:
    def __init__(__self__, *,
                 api_version: Optional[pulumi.Input[_builtins.str]] = None,
                 cloud: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 environment: Optional[pulumi.Input['PluginEnvironmentArgs']] = None,
                 kind: Optional[pulumi.Input[_builtins.str]] = None,
                 runtime_language: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Plugin resources.
        :param pulumi.Input[_builtins.str] api_version: (Required String) The API Version of the schema version of the plugin, for example, `ccpm/v1`.
        :param pulumi.Input[_builtins.str] cloud: Cloud provider where the Custom Connector Plugin archive is uploaded. Accepted values are: `AWS`, `AZURE`, `GCP`.
        :param pulumi.Input[_builtins.str] description: The description of the Plugin.
        :param pulumi.Input[_builtins.str] display_name: The name of the Plugin.
        :param pulumi.Input['PluginEnvironmentArgs'] environment: Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        :param pulumi.Input[_builtins.str] kind: (Required String) The kind of the Plugin, for example, `CustomConnectPlugin`.
        :param pulumi.Input[_builtins.str] runtime_language: (Optional String) Runtime language of the plugin.
        """
        if api_version is not None:
            pulumi.set(__self__, "api_version", api_version)
        if cloud is not None:
            pulumi.set(__self__, "cloud", cloud)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if environment is not None:
            pulumi.set(__self__, "environment", environment)
        if kind is not None:
            pulumi.set(__self__, "kind", kind)
        if runtime_language is not None:
            pulumi.set(__self__, "runtime_language", runtime_language)

    @_builtins.property
    @pulumi.getter(name="apiVersion")
    def api_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Required String) The API Version of the schema version of the plugin, for example, `ccpm/v1`.
        """
        return pulumi.get(self, "api_version")

    @api_version.setter
    def api_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "api_version", value)

    @_builtins.property
    @pulumi.getter
    def cloud(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Cloud provider where the Custom Connector Plugin archive is uploaded. Accepted values are: `AWS`, `AZURE`, `GCP`.
        """
        return pulumi.get(self, "cloud")

    @cloud.setter
    def cloud(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cloud", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the Plugin.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Plugin.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter
    def environment(self) -> Optional[pulumi.Input['PluginEnvironmentArgs']]:
        """
        Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: Optional[pulumi.Input['PluginEnvironmentArgs']]):
        pulumi.set(self, "environment", value)

    @_builtins.property
    @pulumi.getter
    def kind(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Required String) The kind of the Plugin, for example, `CustomConnectPlugin`.
        """
        return pulumi.get(self, "kind")

    @kind.setter
    def kind(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "kind", value)

    @_builtins.property
    @pulumi.getter(name="runtimeLanguage")
    def runtime_language(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Optional String) Runtime language of the plugin.
        """
        return pulumi.get(self, "runtime_language")

    @runtime_language.setter
    def runtime_language(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "runtime_language", value)


@pulumi.type_token("confluentcloud:index/plugin:Plugin")
class Plugin(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cloud: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 environment: Optional[pulumi.Input[Union['PluginEnvironmentArgs', 'PluginEnvironmentArgsDict']]] = None,
                 runtime_language: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ## Import

        You can import a Custom Connector Plugin by using a Plugin ID, in the format `<Environment ID/Custom Connector Plugin ID>`. The following example shows how to import a Plugin:

        $ export CONFLUENT_CLOUD_API_KEY="<cloud_api_key>"

        $ export CONFLUENT_CLOUD_API_SECRET="<cloud_api_secret>"

        ```sh
        $ pulumi import confluentcloud:index/plugin:Plugin main env-123/ccpm-abc123xyz
        ```

        !> **Warning:** Do not forget to delete terminal command history afterwards for security purposes.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cloud: Cloud provider where the Custom Connector Plugin archive is uploaded. Accepted values are: `AWS`, `AZURE`, `GCP`.
        :param pulumi.Input[_builtins.str] description: The description of the Plugin.
        :param pulumi.Input[_builtins.str] display_name: The name of the Plugin.
        :param pulumi.Input[Union['PluginEnvironmentArgs', 'PluginEnvironmentArgsDict']] environment: Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        :param pulumi.Input[_builtins.str] runtime_language: (Optional String) Runtime language of the plugin.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PluginArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ## Import

        You can import a Custom Connector Plugin by using a Plugin ID, in the format `<Environment ID/Custom Connector Plugin ID>`. The following example shows how to import a Plugin:

        $ export CONFLUENT_CLOUD_API_KEY="<cloud_api_key>"

        $ export CONFLUENT_CLOUD_API_SECRET="<cloud_api_secret>"

        ```sh
        $ pulumi import confluentcloud:index/plugin:Plugin main env-123/ccpm-abc123xyz
        ```

        !> **Warning:** Do not forget to delete terminal command history afterwards for security purposes.

        :param str resource_name: The name of the resource.
        :param PluginArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PluginArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cloud: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 environment: Optional[pulumi.Input[Union['PluginEnvironmentArgs', 'PluginEnvironmentArgsDict']]] = None,
                 runtime_language: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PluginArgs.__new__(PluginArgs)

            if cloud is None and not opts.urn:
                raise TypeError("Missing required property 'cloud'")
            __props__.__dict__["cloud"] = cloud
            __props__.__dict__["description"] = description
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            if environment is None and not opts.urn:
                raise TypeError("Missing required property 'environment'")
            __props__.__dict__["environment"] = environment
            __props__.__dict__["runtime_language"] = runtime_language
            __props__.__dict__["api_version"] = None
            __props__.__dict__["kind"] = None
        super(Plugin, __self__).__init__(
            'confluentcloud:index/plugin:Plugin',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            api_version: Optional[pulumi.Input[_builtins.str]] = None,
            cloud: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            display_name: Optional[pulumi.Input[_builtins.str]] = None,
            environment: Optional[pulumi.Input[Union['PluginEnvironmentArgs', 'PluginEnvironmentArgsDict']]] = None,
            kind: Optional[pulumi.Input[_builtins.str]] = None,
            runtime_language: Optional[pulumi.Input[_builtins.str]] = None) -> 'Plugin':
        """
        Get an existing Plugin resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] api_version: (Required String) The API Version of the schema version of the plugin, for example, `ccpm/v1`.
        :param pulumi.Input[_builtins.str] cloud: Cloud provider where the Custom Connector Plugin archive is uploaded. Accepted values are: `AWS`, `AZURE`, `GCP`.
        :param pulumi.Input[_builtins.str] description: The description of the Plugin.
        :param pulumi.Input[_builtins.str] display_name: The name of the Plugin.
        :param pulumi.Input[Union['PluginEnvironmentArgs', 'PluginEnvironmentArgsDict']] environment: Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        :param pulumi.Input[_builtins.str] kind: (Required String) The kind of the Plugin, for example, `CustomConnectPlugin`.
        :param pulumi.Input[_builtins.str] runtime_language: (Optional String) Runtime language of the plugin.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PluginState.__new__(_PluginState)

        __props__.__dict__["api_version"] = api_version
        __props__.__dict__["cloud"] = cloud
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["environment"] = environment
        __props__.__dict__["kind"] = kind
        __props__.__dict__["runtime_language"] = runtime_language
        return Plugin(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="apiVersion")
    def api_version(self) -> pulumi.Output[_builtins.str]:
        """
        (Required String) The API Version of the schema version of the plugin, for example, `ccpm/v1`.
        """
        return pulumi.get(self, "api_version")

    @_builtins.property
    @pulumi.getter
    def cloud(self) -> pulumi.Output[_builtins.str]:
        """
        Cloud provider where the Custom Connector Plugin archive is uploaded. Accepted values are: `AWS`, `AZURE`, `GCP`.
        """
        return pulumi.get(self, "cloud")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The description of the Plugin.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the Plugin.
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter
    def environment(self) -> pulumi.Output['outputs.PluginEnvironment']:
        """
        Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        """
        return pulumi.get(self, "environment")

    @_builtins.property
    @pulumi.getter
    def kind(self) -> pulumi.Output[_builtins.str]:
        """
        (Required String) The kind of the Plugin, for example, `CustomConnectPlugin`.
        """
        return pulumi.get(self, "kind")

    @_builtins.property
    @pulumi.getter(name="runtimeLanguage")
    def runtime_language(self) -> pulumi.Output[_builtins.str]:
        """
        (Optional String) Runtime language of the plugin.
        """
        return pulumi.get(self, "runtime_language")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetGatewayResult',
    'AwaitableGetGatewayResult',
    'get_gateway',
    'get_gateway_output',
]

@pulumi.output_type
class GetGatewayResult:
    """
    A collection of values returned by getGateway.
    """
    def __init__(__self__, aws_egress_private_link_gateways=None, aws_ingress_private_link_gateways=None, aws_peering_gateways=None, aws_private_network_interface_gateways=None, azure_egress_private_link_gateways=None, azure_peering_gateways=None, display_name=None, environment=None, gcp_egress_private_service_connect_gateways=None, gcp_peering_gateways=None, id=None):
        if aws_egress_private_link_gateways and not isinstance(aws_egress_private_link_gateways, list):
            raise TypeError("Expected argument 'aws_egress_private_link_gateways' to be a list")
        pulumi.set(__self__, "aws_egress_private_link_gateways", aws_egress_private_link_gateways)
        if aws_ingress_private_link_gateways and not isinstance(aws_ingress_private_link_gateways, list):
            raise TypeError("Expected argument 'aws_ingress_private_link_gateways' to be a list")
        pulumi.set(__self__, "aws_ingress_private_link_gateways", aws_ingress_private_link_gateways)
        if aws_peering_gateways and not isinstance(aws_peering_gateways, list):
            raise TypeError("Expected argument 'aws_peering_gateways' to be a list")
        pulumi.set(__self__, "aws_peering_gateways", aws_peering_gateways)
        if aws_private_network_interface_gateways and not isinstance(aws_private_network_interface_gateways, list):
            raise TypeError("Expected argument 'aws_private_network_interface_gateways' to be a list")
        pulumi.set(__self__, "aws_private_network_interface_gateways", aws_private_network_interface_gateways)
        if azure_egress_private_link_gateways and not isinstance(azure_egress_private_link_gateways, list):
            raise TypeError("Expected argument 'azure_egress_private_link_gateways' to be a list")
        pulumi.set(__self__, "azure_egress_private_link_gateways", azure_egress_private_link_gateways)
        if azure_peering_gateways and not isinstance(azure_peering_gateways, list):
            raise TypeError("Expected argument 'azure_peering_gateways' to be a list")
        pulumi.set(__self__, "azure_peering_gateways", azure_peering_gateways)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if environment and not isinstance(environment, dict):
            raise TypeError("Expected argument 'environment' to be a dict")
        pulumi.set(__self__, "environment", environment)
        if gcp_egress_private_service_connect_gateways and not isinstance(gcp_egress_private_service_connect_gateways, list):
            raise TypeError("Expected argument 'gcp_egress_private_service_connect_gateways' to be a list")
        pulumi.set(__self__, "gcp_egress_private_service_connect_gateways", gcp_egress_private_service_connect_gateways)
        if gcp_peering_gateways and not isinstance(gcp_peering_gateways, list):
            raise TypeError("Expected argument 'gcp_peering_gateways' to be a list")
        pulumi.set(__self__, "gcp_peering_gateways", gcp_peering_gateways)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @_builtins.property
    @pulumi.getter(name="awsEgressPrivateLinkGateways")
    def aws_egress_private_link_gateways(self) -> Sequence['outputs.GetGatewayAwsEgressPrivateLinkGatewayResult']:
        """
        (Optional Configuration Block) supports the following:
        """
        return pulumi.get(self, "aws_egress_private_link_gateways")

    @_builtins.property
    @pulumi.getter(name="awsIngressPrivateLinkGateways")
    def aws_ingress_private_link_gateways(self) -> Sequence['outputs.GetGatewayAwsIngressPrivateLinkGatewayResult']:
        """
        (Optional Configuration Block) supports the following:
        """
        return pulumi.get(self, "aws_ingress_private_link_gateways")

    @_builtins.property
    @pulumi.getter(name="awsPeeringGateways")
    def aws_peering_gateways(self) -> Sequence['outputs.GetGatewayAwsPeeringGatewayResult']:
        """
        (Optional Configuration Block) supports the following:
        """
        return pulumi.get(self, "aws_peering_gateways")

    @_builtins.property
    @pulumi.getter(name="awsPrivateNetworkInterfaceGateways")
    def aws_private_network_interface_gateways(self) -> Sequence['outputs.GetGatewayAwsPrivateNetworkInterfaceGatewayResult']:
        """
        (Optional Configuration Block) supports the following:
        """
        return pulumi.get(self, "aws_private_network_interface_gateways")

    @_builtins.property
    @pulumi.getter(name="azureEgressPrivateLinkGateways")
    def azure_egress_private_link_gateways(self) -> Sequence['outputs.GetGatewayAzureEgressPrivateLinkGatewayResult']:
        """
        (Optional Configuration Block) supports the following:
        """
        return pulumi.get(self, "azure_egress_private_link_gateways")

    @_builtins.property
    @pulumi.getter(name="azurePeeringGateways")
    def azure_peering_gateways(self) -> Sequence['outputs.GetGatewayAzurePeeringGatewayResult']:
        """
        (Optional Configuration Block) supports the following:
        """
        return pulumi.get(self, "azure_peering_gateways")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> _builtins.str:
        """
        (Required String) A human-readable name for the Gateway.
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter
    def environment(self) -> 'outputs.GetGatewayEnvironmentResult':
        return pulumi.get(self, "environment")

    @_builtins.property
    @pulumi.getter(name="gcpEgressPrivateServiceConnectGateways")
    def gcp_egress_private_service_connect_gateways(self) -> Sequence['outputs.GetGatewayGcpEgressPrivateServiceConnectGatewayResult']:
        """
        (Optional Configuration Block) supports the following:
        """
        return pulumi.get(self, "gcp_egress_private_service_connect_gateways")

    @_builtins.property
    @pulumi.getter(name="gcpPeeringGateways")
    def gcp_peering_gateways(self) -> Sequence['outputs.GetGatewayGcpPeeringGatewayResult']:
        """
        (Optional Configuration Block) supports the following:
        """
        return pulumi.get(self, "gcp_peering_gateways")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")


class AwaitableGetGatewayResult(GetGatewayResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGatewayResult(
            aws_egress_private_link_gateways=self.aws_egress_private_link_gateways,
            aws_ingress_private_link_gateways=self.aws_ingress_private_link_gateways,
            aws_peering_gateways=self.aws_peering_gateways,
            aws_private_network_interface_gateways=self.aws_private_network_interface_gateways,
            azure_egress_private_link_gateways=self.azure_egress_private_link_gateways,
            azure_peering_gateways=self.azure_peering_gateways,
            display_name=self.display_name,
            environment=self.environment,
            gcp_egress_private_service_connect_gateways=self.gcp_egress_private_service_connect_gateways,
            gcp_peering_gateways=self.gcp_peering_gateways,
            id=self.id)


def get_gateway(environment: Optional[Union['GetGatewayEnvironmentArgs', 'GetGatewayEnvironmentArgsDict']] = None,
                id: Optional[_builtins.str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGatewayResult:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `Gateway` describes a Gateway data source.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    main = confluentcloud.get_gateway(id="gw-abc123",
        environment={
            "id": "env-123abc",
        })
    pulumi.export("gateway", main)
    ```


    :param _builtins.str id: The ID of the Gateway, for example, `gw-abc123`.
    """
    __args__ = dict()
    __args__['environment'] = environment
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('confluentcloud:index/getGateway:getGateway', __args__, opts=opts, typ=GetGatewayResult).value

    return AwaitableGetGatewayResult(
        aws_egress_private_link_gateways=pulumi.get(__ret__, 'aws_egress_private_link_gateways'),
        aws_ingress_private_link_gateways=pulumi.get(__ret__, 'aws_ingress_private_link_gateways'),
        aws_peering_gateways=pulumi.get(__ret__, 'aws_peering_gateways'),
        aws_private_network_interface_gateways=pulumi.get(__ret__, 'aws_private_network_interface_gateways'),
        azure_egress_private_link_gateways=pulumi.get(__ret__, 'azure_egress_private_link_gateways'),
        azure_peering_gateways=pulumi.get(__ret__, 'azure_peering_gateways'),
        display_name=pulumi.get(__ret__, 'display_name'),
        environment=pulumi.get(__ret__, 'environment'),
        gcp_egress_private_service_connect_gateways=pulumi.get(__ret__, 'gcp_egress_private_service_connect_gateways'),
        gcp_peering_gateways=pulumi.get(__ret__, 'gcp_peering_gateways'),
        id=pulumi.get(__ret__, 'id'))
def get_gateway_output(environment: Optional[pulumi.Input[Union['GetGatewayEnvironmentArgs', 'GetGatewayEnvironmentArgsDict']]] = None,
                       id: Optional[pulumi.Input[_builtins.str]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGatewayResult]:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `Gateway` describes a Gateway data source.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    main = confluentcloud.get_gateway(id="gw-abc123",
        environment={
            "id": "env-123abc",
        })
    pulumi.export("gateway", main)
    ```


    :param _builtins.str id: The ID of the Gateway, for example, `gw-abc123`.
    """
    __args__ = dict()
    __args__['environment'] = environment
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('confluentcloud:index/getGateway:getGateway', __args__, opts=opts, typ=GetGatewayResult)
    return __ret__.apply(lambda __response__: GetGatewayResult(
        aws_egress_private_link_gateways=pulumi.get(__response__, 'aws_egress_private_link_gateways'),
        aws_ingress_private_link_gateways=pulumi.get(__response__, 'aws_ingress_private_link_gateways'),
        aws_peering_gateways=pulumi.get(__response__, 'aws_peering_gateways'),
        aws_private_network_interface_gateways=pulumi.get(__response__, 'aws_private_network_interface_gateways'),
        azure_egress_private_link_gateways=pulumi.get(__response__, 'azure_egress_private_link_gateways'),
        azure_peering_gateways=pulumi.get(__response__, 'azure_peering_gateways'),
        display_name=pulumi.get(__response__, 'display_name'),
        environment=pulumi.get(__response__, 'environment'),
        gcp_egress_private_service_connect_gateways=pulumi.get(__response__, 'gcp_egress_private_service_connect_gateways'),
        gcp_peering_gateways=pulumi.get(__response__, 'gcp_peering_gateways'),
        id=pulumi.get(__response__, 'id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['FlinkConnectionArgs', 'FlinkConnection']

@pulumi.input_type
class FlinkConnectionArgs:
    def __init__(__self__, *,
                 display_name: pulumi.Input[_builtins.str],
                 endpoint: pulumi.Input[_builtins.str],
                 type: pulumi.Input[_builtins.str],
                 api_key: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_session_token: Optional[pulumi.Input[_builtins.str]] = None,
                 compute_pool: Optional[pulumi.Input['FlinkConnectionComputePoolArgs']] = None,
                 credentials: Optional[pulumi.Input['FlinkConnectionCredentialsArgs']] = None,
                 environment: Optional[pulumi.Input['FlinkConnectionEnvironmentArgs']] = None,
                 organization: Optional[pulumi.Input['FlinkConnectionOrganizationArgs']] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 principal: Optional[pulumi.Input['FlinkConnectionPrincipalArgs']] = None,
                 rest_endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 service_key: Optional[pulumi.Input[_builtins.str]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a FlinkConnection resource.
        :param pulumi.Input[_builtins.str] display_name: The unique name of the Flink Connection per organization, environment scope.
        :param pulumi.Input[_builtins.str] endpoint: The endpoint of the flink connection.
        :param pulumi.Input[_builtins.str] type: The type of the flink connection.
        :param pulumi.Input[_builtins.str] api_key: API key for the type.
        :param pulumi.Input[_builtins.str] aws_access_key: Access key for the type.
        :param pulumi.Input[_builtins.str] aws_secret_key: Secret key for the type.
        :param pulumi.Input[_builtins.str] aws_session_token: Session token for the type.
        :param pulumi.Input['FlinkConnectionCredentialsArgs'] credentials: The Cluster API Credentials.
        :param pulumi.Input[_builtins.str] password: Password for the type.
        :param pulumi.Input[_builtins.str] rest_endpoint: The REST endpoint of the Flink Connection cluster, for example, `https://flink.us-east-1.aws.confluent.cloud/sql/v1/organizations/1111aaaa-11aa-11aa-11aa-111111aaaaaa/environments/env-abc123`).
        :param pulumi.Input[_builtins.str] service_key: Service Key for the type.
        :param pulumi.Input[_builtins.str] username: Username for the type.
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "endpoint", endpoint)
        pulumi.set(__self__, "type", type)
        if api_key is not None:
            pulumi.set(__self__, "api_key", api_key)
        if aws_access_key is not None:
            pulumi.set(__self__, "aws_access_key", aws_access_key)
        if aws_secret_key is not None:
            pulumi.set(__self__, "aws_secret_key", aws_secret_key)
        if aws_session_token is not None:
            pulumi.set(__self__, "aws_session_token", aws_session_token)
        if compute_pool is not None:
            pulumi.set(__self__, "compute_pool", compute_pool)
        if credentials is not None:
            pulumi.set(__self__, "credentials", credentials)
        if environment is not None:
            pulumi.set(__self__, "environment", environment)
        if organization is not None:
            pulumi.set(__self__, "organization", organization)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if principal is not None:
            pulumi.set(__self__, "principal", principal)
        if rest_endpoint is not None:
            pulumi.set(__self__, "rest_endpoint", rest_endpoint)
        if service_key is not None:
            pulumi.set(__self__, "service_key", service_key)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[_builtins.str]:
        """
        The unique name of the Flink Connection per organization, environment scope.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> pulumi.Input[_builtins.str]:
        """
        The endpoint of the flink connection.
        """
        return pulumi.get(self, "endpoint")

    @endpoint.setter
    def endpoint(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "endpoint", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of the flink connection.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="apiKey")
    def api_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        API key for the type.
        """
        return pulumi.get(self, "api_key")

    @api_key.setter
    def api_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "api_key", value)

    @_builtins.property
    @pulumi.getter(name="awsAccessKey")
    def aws_access_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Access key for the type.
        """
        return pulumi.get(self, "aws_access_key")

    @aws_access_key.setter
    def aws_access_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "aws_access_key", value)

    @_builtins.property
    @pulumi.getter(name="awsSecretKey")
    def aws_secret_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Secret key for the type.
        """
        return pulumi.get(self, "aws_secret_key")

    @aws_secret_key.setter
    def aws_secret_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "aws_secret_key", value)

    @_builtins.property
    @pulumi.getter(name="awsSessionToken")
    def aws_session_token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Session token for the type.
        """
        return pulumi.get(self, "aws_session_token")

    @aws_session_token.setter
    def aws_session_token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "aws_session_token", value)

    @_builtins.property
    @pulumi.getter(name="computePool")
    def compute_pool(self) -> Optional[pulumi.Input['FlinkConnectionComputePoolArgs']]:
        return pulumi.get(self, "compute_pool")

    @compute_pool.setter
    def compute_pool(self, value: Optional[pulumi.Input['FlinkConnectionComputePoolArgs']]):
        pulumi.set(self, "compute_pool", value)

    @_builtins.property
    @pulumi.getter
    def credentials(self) -> Optional[pulumi.Input['FlinkConnectionCredentialsArgs']]:
        """
        The Cluster API Credentials.
        """
        return pulumi.get(self, "credentials")

    @credentials.setter
    def credentials(self, value: Optional[pulumi.Input['FlinkConnectionCredentialsArgs']]):
        pulumi.set(self, "credentials", value)

    @_builtins.property
    @pulumi.getter
    def environment(self) -> Optional[pulumi.Input['FlinkConnectionEnvironmentArgs']]:
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: Optional[pulumi.Input['FlinkConnectionEnvironmentArgs']]):
        pulumi.set(self, "environment", value)

    @_builtins.property
    @pulumi.getter
    def organization(self) -> Optional[pulumi.Input['FlinkConnectionOrganizationArgs']]:
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: Optional[pulumi.Input['FlinkConnectionOrganizationArgs']]):
        pulumi.set(self, "organization", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Password for the type.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter
    def principal(self) -> Optional[pulumi.Input['FlinkConnectionPrincipalArgs']]:
        return pulumi.get(self, "principal")

    @principal.setter
    def principal(self, value: Optional[pulumi.Input['FlinkConnectionPrincipalArgs']]):
        pulumi.set(self, "principal", value)

    @_builtins.property
    @pulumi.getter(name="restEndpoint")
    def rest_endpoint(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The REST endpoint of the Flink Connection cluster, for example, `https://flink.us-east-1.aws.confluent.cloud/sql/v1/organizations/1111aaaa-11aa-11aa-11aa-111111aaaaaa/environments/env-abc123`).
        """
        return pulumi.get(self, "rest_endpoint")

    @rest_endpoint.setter
    def rest_endpoint(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "rest_endpoint", value)

    @_builtins.property
    @pulumi.getter(name="serviceKey")
    def service_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Service Key for the type.
        """
        return pulumi.get(self, "service_key")

    @service_key.setter
    def service_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_key", value)

    @_builtins.property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Username for the type.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "username", value)


@pulumi.input_type
class _FlinkConnectionState:
    def __init__(__self__, *,
                 api_key: Optional[pulumi.Input[_builtins.str]] = None,
                 api_version: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_session_token: Optional[pulumi.Input[_builtins.str]] = None,
                 compute_pool: Optional[pulumi.Input['FlinkConnectionComputePoolArgs']] = None,
                 credentials: Optional[pulumi.Input['FlinkConnectionCredentialsArgs']] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 environment: Optional[pulumi.Input['FlinkConnectionEnvironmentArgs']] = None,
                 kind: Optional[pulumi.Input[_builtins.str]] = None,
                 organization: Optional[pulumi.Input['FlinkConnectionOrganizationArgs']] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 principal: Optional[pulumi.Input['FlinkConnectionPrincipalArgs']] = None,
                 rest_endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 service_key: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering FlinkConnection resources.
        :param pulumi.Input[_builtins.str] api_key: API key for the type.
        :param pulumi.Input[_builtins.str] api_version: The schema version of this representation of a resource.
        :param pulumi.Input[_builtins.str] aws_access_key: Access key for the type.
        :param pulumi.Input[_builtins.str] aws_secret_key: Secret key for the type.
        :param pulumi.Input[_builtins.str] aws_session_token: Session token for the type.
        :param pulumi.Input['FlinkConnectionCredentialsArgs'] credentials: The Cluster API Credentials.
        :param pulumi.Input[_builtins.str] display_name: The unique name of the Flink Connection per organization, environment scope.
        :param pulumi.Input[_builtins.str] endpoint: The endpoint of the flink connection.
        :param pulumi.Input[_builtins.str] kind: The object this REST resource represents.
        :param pulumi.Input[_builtins.str] password: Password for the type.
        :param pulumi.Input[_builtins.str] rest_endpoint: The REST endpoint of the Flink Connection cluster, for example, `https://flink.us-east-1.aws.confluent.cloud/sql/v1/organizations/1111aaaa-11aa-11aa-11aa-111111aaaaaa/environments/env-abc123`).
        :param pulumi.Input[_builtins.str] service_key: Service Key for the type.
        :param pulumi.Input[_builtins.str] type: The type of the flink connection.
        :param pulumi.Input[_builtins.str] username: Username for the type.
        """
        if api_key is not None:
            pulumi.set(__self__, "api_key", api_key)
        if api_version is not None:
            pulumi.set(__self__, "api_version", api_version)
        if aws_access_key is not None:
            pulumi.set(__self__, "aws_access_key", aws_access_key)
        if aws_secret_key is not None:
            pulumi.set(__self__, "aws_secret_key", aws_secret_key)
        if aws_session_token is not None:
            pulumi.set(__self__, "aws_session_token", aws_session_token)
        if compute_pool is not None:
            pulumi.set(__self__, "compute_pool", compute_pool)
        if credentials is not None:
            pulumi.set(__self__, "credentials", credentials)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if endpoint is not None:
            pulumi.set(__self__, "endpoint", endpoint)
        if environment is not None:
            pulumi.set(__self__, "environment", environment)
        if kind is not None:
            pulumi.set(__self__, "kind", kind)
        if organization is not None:
            pulumi.set(__self__, "organization", organization)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if principal is not None:
            pulumi.set(__self__, "principal", principal)
        if rest_endpoint is not None:
            pulumi.set(__self__, "rest_endpoint", rest_endpoint)
        if service_key is not None:
            pulumi.set(__self__, "service_key", service_key)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @_builtins.property
    @pulumi.getter(name="apiKey")
    def api_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        API key for the type.
        """
        return pulumi.get(self, "api_key")

    @api_key.setter
    def api_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "api_key", value)

    @_builtins.property
    @pulumi.getter(name="apiVersion")
    def api_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The schema version of this representation of a resource.
        """
        return pulumi.get(self, "api_version")

    @api_version.setter
    def api_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "api_version", value)

    @_builtins.property
    @pulumi.getter(name="awsAccessKey")
    def aws_access_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Access key for the type.
        """
        return pulumi.get(self, "aws_access_key")

    @aws_access_key.setter
    def aws_access_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "aws_access_key", value)

    @_builtins.property
    @pulumi.getter(name="awsSecretKey")
    def aws_secret_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Secret key for the type.
        """
        return pulumi.get(self, "aws_secret_key")

    @aws_secret_key.setter
    def aws_secret_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "aws_secret_key", value)

    @_builtins.property
    @pulumi.getter(name="awsSessionToken")
    def aws_session_token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Session token for the type.
        """
        return pulumi.get(self, "aws_session_token")

    @aws_session_token.setter
    def aws_session_token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "aws_session_token", value)

    @_builtins.property
    @pulumi.getter(name="computePool")
    def compute_pool(self) -> Optional[pulumi.Input['FlinkConnectionComputePoolArgs']]:
        return pulumi.get(self, "compute_pool")

    @compute_pool.setter
    def compute_pool(self, value: Optional[pulumi.Input['FlinkConnectionComputePoolArgs']]):
        pulumi.set(self, "compute_pool", value)

    @_builtins.property
    @pulumi.getter
    def credentials(self) -> Optional[pulumi.Input['FlinkConnectionCredentialsArgs']]:
        """
        The Cluster API Credentials.
        """
        return pulumi.get(self, "credentials")

    @credentials.setter
    def credentials(self, value: Optional[pulumi.Input['FlinkConnectionCredentialsArgs']]):
        pulumi.set(self, "credentials", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique name of the Flink Connection per organization, environment scope.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The endpoint of the flink connection.
        """
        return pulumi.get(self, "endpoint")

    @endpoint.setter
    def endpoint(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "endpoint", value)

    @_builtins.property
    @pulumi.getter
    def environment(self) -> Optional[pulumi.Input['FlinkConnectionEnvironmentArgs']]:
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: Optional[pulumi.Input['FlinkConnectionEnvironmentArgs']]):
        pulumi.set(self, "environment", value)

    @_builtins.property
    @pulumi.getter
    def kind(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The object this REST resource represents.
        """
        return pulumi.get(self, "kind")

    @kind.setter
    def kind(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "kind", value)

    @_builtins.property
    @pulumi.getter
    def organization(self) -> Optional[pulumi.Input['FlinkConnectionOrganizationArgs']]:
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: Optional[pulumi.Input['FlinkConnectionOrganizationArgs']]):
        pulumi.set(self, "organization", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Password for the type.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter
    def principal(self) -> Optional[pulumi.Input['FlinkConnectionPrincipalArgs']]:
        return pulumi.get(self, "principal")

    @principal.setter
    def principal(self, value: Optional[pulumi.Input['FlinkConnectionPrincipalArgs']]):
        pulumi.set(self, "principal", value)

    @_builtins.property
    @pulumi.getter(name="restEndpoint")
    def rest_endpoint(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The REST endpoint of the Flink Connection cluster, for example, `https://flink.us-east-1.aws.confluent.cloud/sql/v1/organizations/1111aaaa-11aa-11aa-11aa-111111aaaaaa/environments/env-abc123`).
        """
        return pulumi.get(self, "rest_endpoint")

    @rest_endpoint.setter
    def rest_endpoint(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "rest_endpoint", value)

    @_builtins.property
    @pulumi.getter(name="serviceKey")
    def service_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Service Key for the type.
        """
        return pulumi.get(self, "service_key")

    @service_key.setter
    def service_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_key", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the flink connection.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Username for the type.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "username", value)


@pulumi.type_token("confluentcloud:index/flinkConnection:FlinkConnection")
class FlinkConnection(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_key: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_session_token: Optional[pulumi.Input[_builtins.str]] = None,
                 compute_pool: Optional[pulumi.Input[Union['FlinkConnectionComputePoolArgs', 'FlinkConnectionComputePoolArgsDict']]] = None,
                 credentials: Optional[pulumi.Input[Union['FlinkConnectionCredentialsArgs', 'FlinkConnectionCredentialsArgsDict']]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 environment: Optional[pulumi.Input[Union['FlinkConnectionEnvironmentArgs', 'FlinkConnectionEnvironmentArgsDict']]] = None,
                 organization: Optional[pulumi.Input[Union['FlinkConnectionOrganizationArgs', 'FlinkConnectionOrganizationArgsDict']]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 principal: Optional[pulumi.Input[Union['FlinkConnectionPrincipalArgs', 'FlinkConnectionPrincipalArgsDict']]] = None,
                 rest_endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 service_key: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Import

        You can import a Flink connection by using the Flink Connection name, for example:

        Option #1: Manage multiple Flink Compute Pools in the same Pulumi Stack

        $ export IMPORT_CONFLUENT_ORGANIZATION_ID="<organization_id>"

        $ export IMPORT_CONFLUENT_ENVIRONMENT_ID="<environment_id>"

        $ export IMPORT_FLINK_COMPUTE_POOL_ID="<flink_compute_pool_id>"

        $ export IMPORT_FLINK_API_KEY="<flink_api_key>"

        $ export IMPORT_FLINK_API_SECRET="<flink_api_secret>"

        $ export IMPORT_FLINK_REST_ENDPOINT="<flink_rest_endpoint>"

        $ export IMPORT_FLINK_PRINCIPAL_ID="<flink_principal>"

        $ export API_KEY="<API_KEY>"

        ```sh
        $ pulumi import confluentcloud:index/flinkConnection:FlinkConnection example org-xyz123/env-abc123/connection1
        ```

        Option #2: Manage a single Flink Compute Pool in the same Pulumi Stack

        $ export API_KEY="<API_KEY>"

        ```sh
        $ pulumi import confluentcloud:index/flinkConnection:FlinkConnection example org-xyz123/env-abc123/connection1
        ```

        !> **Warning:** Do not forget to delete terminal command history afterwards for security purposes.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] api_key: API key for the type.
        :param pulumi.Input[_builtins.str] aws_access_key: Access key for the type.
        :param pulumi.Input[_builtins.str] aws_secret_key: Secret key for the type.
        :param pulumi.Input[_builtins.str] aws_session_token: Session token for the type.
        :param pulumi.Input[Union['FlinkConnectionCredentialsArgs', 'FlinkConnectionCredentialsArgsDict']] credentials: The Cluster API Credentials.
        :param pulumi.Input[_builtins.str] display_name: The unique name of the Flink Connection per organization, environment scope.
        :param pulumi.Input[_builtins.str] endpoint: The endpoint of the flink connection.
        :param pulumi.Input[_builtins.str] password: Password for the type.
        :param pulumi.Input[_builtins.str] rest_endpoint: The REST endpoint of the Flink Connection cluster, for example, `https://flink.us-east-1.aws.confluent.cloud/sql/v1/organizations/1111aaaa-11aa-11aa-11aa-111111aaaaaa/environments/env-abc123`).
        :param pulumi.Input[_builtins.str] service_key: Service Key for the type.
        :param pulumi.Input[_builtins.str] type: The type of the flink connection.
        :param pulumi.Input[_builtins.str] username: Username for the type.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FlinkConnectionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        You can import a Flink connection by using the Flink Connection name, for example:

        Option #1: Manage multiple Flink Compute Pools in the same Pulumi Stack

        $ export IMPORT_CONFLUENT_ORGANIZATION_ID="<organization_id>"

        $ export IMPORT_CONFLUENT_ENVIRONMENT_ID="<environment_id>"

        $ export IMPORT_FLINK_COMPUTE_POOL_ID="<flink_compute_pool_id>"

        $ export IMPORT_FLINK_API_KEY="<flink_api_key>"

        $ export IMPORT_FLINK_API_SECRET="<flink_api_secret>"

        $ export IMPORT_FLINK_REST_ENDPOINT="<flink_rest_endpoint>"

        $ export IMPORT_FLINK_PRINCIPAL_ID="<flink_principal>"

        $ export API_KEY="<API_KEY>"

        ```sh
        $ pulumi import confluentcloud:index/flinkConnection:FlinkConnection example org-xyz123/env-abc123/connection1
        ```

        Option #2: Manage a single Flink Compute Pool in the same Pulumi Stack

        $ export API_KEY="<API_KEY>"

        ```sh
        $ pulumi import confluentcloud:index/flinkConnection:FlinkConnection example org-xyz123/env-abc123/connection1
        ```

        !> **Warning:** Do not forget to delete terminal command history afterwards for security purposes.

        :param str resource_name: The name of the resource.
        :param FlinkConnectionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FlinkConnectionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_key: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_session_token: Optional[pulumi.Input[_builtins.str]] = None,
                 compute_pool: Optional[pulumi.Input[Union['FlinkConnectionComputePoolArgs', 'FlinkConnectionComputePoolArgsDict']]] = None,
                 credentials: Optional[pulumi.Input[Union['FlinkConnectionCredentialsArgs', 'FlinkConnectionCredentialsArgsDict']]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 environment: Optional[pulumi.Input[Union['FlinkConnectionEnvironmentArgs', 'FlinkConnectionEnvironmentArgsDict']]] = None,
                 organization: Optional[pulumi.Input[Union['FlinkConnectionOrganizationArgs', 'FlinkConnectionOrganizationArgsDict']]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 principal: Optional[pulumi.Input[Union['FlinkConnectionPrincipalArgs', 'FlinkConnectionPrincipalArgsDict']]] = None,
                 rest_endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 service_key: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FlinkConnectionArgs.__new__(FlinkConnectionArgs)

            __props__.__dict__["api_key"] = api_key
            __props__.__dict__["aws_access_key"] = aws_access_key
            __props__.__dict__["aws_secret_key"] = aws_secret_key
            __props__.__dict__["aws_session_token"] = aws_session_token
            __props__.__dict__["compute_pool"] = compute_pool
            __props__.__dict__["credentials"] = None if credentials is None else pulumi.Output.secret(credentials)
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            if endpoint is None and not opts.urn:
                raise TypeError("Missing required property 'endpoint'")
            __props__.__dict__["endpoint"] = endpoint
            __props__.__dict__["environment"] = environment
            __props__.__dict__["organization"] = organization
            __props__.__dict__["password"] = password
            __props__.__dict__["principal"] = principal
            __props__.__dict__["rest_endpoint"] = rest_endpoint
            __props__.__dict__["service_key"] = service_key
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["username"] = username
            __props__.__dict__["api_version"] = None
            __props__.__dict__["kind"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["credentials"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(FlinkConnection, __self__).__init__(
            'confluentcloud:index/flinkConnection:FlinkConnection',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            api_key: Optional[pulumi.Input[_builtins.str]] = None,
            api_version: Optional[pulumi.Input[_builtins.str]] = None,
            aws_access_key: Optional[pulumi.Input[_builtins.str]] = None,
            aws_secret_key: Optional[pulumi.Input[_builtins.str]] = None,
            aws_session_token: Optional[pulumi.Input[_builtins.str]] = None,
            compute_pool: Optional[pulumi.Input[Union['FlinkConnectionComputePoolArgs', 'FlinkConnectionComputePoolArgsDict']]] = None,
            credentials: Optional[pulumi.Input[Union['FlinkConnectionCredentialsArgs', 'FlinkConnectionCredentialsArgsDict']]] = None,
            display_name: Optional[pulumi.Input[_builtins.str]] = None,
            endpoint: Optional[pulumi.Input[_builtins.str]] = None,
            environment: Optional[pulumi.Input[Union['FlinkConnectionEnvironmentArgs', 'FlinkConnectionEnvironmentArgsDict']]] = None,
            kind: Optional[pulumi.Input[_builtins.str]] = None,
            organization: Optional[pulumi.Input[Union['FlinkConnectionOrganizationArgs', 'FlinkConnectionOrganizationArgsDict']]] = None,
            password: Optional[pulumi.Input[_builtins.str]] = None,
            principal: Optional[pulumi.Input[Union['FlinkConnectionPrincipalArgs', 'FlinkConnectionPrincipalArgsDict']]] = None,
            rest_endpoint: Optional[pulumi.Input[_builtins.str]] = None,
            service_key: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None,
            username: Optional[pulumi.Input[_builtins.str]] = None) -> 'FlinkConnection':
        """
        Get an existing FlinkConnection resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] api_key: API key for the type.
        :param pulumi.Input[_builtins.str] api_version: The schema version of this representation of a resource.
        :param pulumi.Input[_builtins.str] aws_access_key: Access key for the type.
        :param pulumi.Input[_builtins.str] aws_secret_key: Secret key for the type.
        :param pulumi.Input[_builtins.str] aws_session_token: Session token for the type.
        :param pulumi.Input[Union['FlinkConnectionCredentialsArgs', 'FlinkConnectionCredentialsArgsDict']] credentials: The Cluster API Credentials.
        :param pulumi.Input[_builtins.str] display_name: The unique name of the Flink Connection per organization, environment scope.
        :param pulumi.Input[_builtins.str] endpoint: The endpoint of the flink connection.
        :param pulumi.Input[_builtins.str] kind: The object this REST resource represents.
        :param pulumi.Input[_builtins.str] password: Password for the type.
        :param pulumi.Input[_builtins.str] rest_endpoint: The REST endpoint of the Flink Connection cluster, for example, `https://flink.us-east-1.aws.confluent.cloud/sql/v1/organizations/1111aaaa-11aa-11aa-11aa-111111aaaaaa/environments/env-abc123`).
        :param pulumi.Input[_builtins.str] service_key: Service Key for the type.
        :param pulumi.Input[_builtins.str] type: The type of the flink connection.
        :param pulumi.Input[_builtins.str] username: Username for the type.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FlinkConnectionState.__new__(_FlinkConnectionState)

        __props__.__dict__["api_key"] = api_key
        __props__.__dict__["api_version"] = api_version
        __props__.__dict__["aws_access_key"] = aws_access_key
        __props__.__dict__["aws_secret_key"] = aws_secret_key
        __props__.__dict__["aws_session_token"] = aws_session_token
        __props__.__dict__["compute_pool"] = compute_pool
        __props__.__dict__["credentials"] = credentials
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["endpoint"] = endpoint
        __props__.__dict__["environment"] = environment
        __props__.__dict__["kind"] = kind
        __props__.__dict__["organization"] = organization
        __props__.__dict__["password"] = password
        __props__.__dict__["principal"] = principal
        __props__.__dict__["rest_endpoint"] = rest_endpoint
        __props__.__dict__["service_key"] = service_key
        __props__.__dict__["type"] = type
        __props__.__dict__["username"] = username
        return FlinkConnection(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="apiKey")
    def api_key(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        API key for the type.
        """
        return pulumi.get(self, "api_key")

    @_builtins.property
    @pulumi.getter(name="apiVersion")
    def api_version(self) -> pulumi.Output[_builtins.str]:
        """
        The schema version of this representation of a resource.
        """
        return pulumi.get(self, "api_version")

    @_builtins.property
    @pulumi.getter(name="awsAccessKey")
    def aws_access_key(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Access key for the type.
        """
        return pulumi.get(self, "aws_access_key")

    @_builtins.property
    @pulumi.getter(name="awsSecretKey")
    def aws_secret_key(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Secret key for the type.
        """
        return pulumi.get(self, "aws_secret_key")

    @_builtins.property
    @pulumi.getter(name="awsSessionToken")
    def aws_session_token(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Session token for the type.
        """
        return pulumi.get(self, "aws_session_token")

    @_builtins.property
    @pulumi.getter(name="computePool")
    def compute_pool(self) -> pulumi.Output['outputs.FlinkConnectionComputePool']:
        return pulumi.get(self, "compute_pool")

    @_builtins.property
    @pulumi.getter
    def credentials(self) -> pulumi.Output[Optional['outputs.FlinkConnectionCredentials']]:
        """
        The Cluster API Credentials.
        """
        return pulumi.get(self, "credentials")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[_builtins.str]:
        """
        The unique name of the Flink Connection per organization, environment scope.
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> pulumi.Output[_builtins.str]:
        """
        The endpoint of the flink connection.
        """
        return pulumi.get(self, "endpoint")

    @_builtins.property
    @pulumi.getter
    def environment(self) -> pulumi.Output['outputs.FlinkConnectionEnvironment']:
        return pulumi.get(self, "environment")

    @_builtins.property
    @pulumi.getter
    def kind(self) -> pulumi.Output[_builtins.str]:
        """
        The object this REST resource represents.
        """
        return pulumi.get(self, "kind")

    @_builtins.property
    @pulumi.getter
    def organization(self) -> pulumi.Output['outputs.FlinkConnectionOrganization']:
        return pulumi.get(self, "organization")

    @_builtins.property
    @pulumi.getter
    def password(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Password for the type.
        """
        return pulumi.get(self, "password")

    @_builtins.property
    @pulumi.getter
    def principal(self) -> pulumi.Output['outputs.FlinkConnectionPrincipal']:
        return pulumi.get(self, "principal")

    @_builtins.property
    @pulumi.getter(name="restEndpoint")
    def rest_endpoint(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The REST endpoint of the Flink Connection cluster, for example, `https://flink.us-east-1.aws.confluent.cloud/sql/v1/organizations/1111aaaa-11aa-11aa-11aa-111111aaaaaa/environments/env-abc123`).
        """
        return pulumi.get(self, "rest_endpoint")

    @_builtins.property
    @pulumi.getter(name="serviceKey")
    def service_key(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Service Key for the type.
        """
        return pulumi.get(self, "service_key")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of the flink connection.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter
    def username(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Username for the type.
        """
        return pulumi.get(self, "username")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'Oauth',
]

@pulumi.output_type
class Oauth(dict):
    def __init__(__self__, *,
                 oauth_identity_pool_id: _builtins.str,
                 oauth_external_access_token: Optional[_builtins.str] = None,
                 oauth_external_client_id: Optional[_builtins.str] = None,
                 oauth_external_client_secret: Optional[_builtins.str] = None,
                 oauth_external_token_scope: Optional[_builtins.str] = None,
                 oauth_external_token_url: Optional[_builtins.str] = None,
                 oauth_sts_token_expired_in_seconds: Optional[_builtins.str] = None):
        """
        :param _builtins.str oauth_identity_pool_id: OAuth identity pool id used for processing external token and exchange STS token, registered with Confluent Cloud.
        :param _builtins.str oauth_external_access_token: OAuth existing static access token already fetched from external Identity Provider.
        :param _builtins.str oauth_external_client_id: OAuth token application client id from external Identity Provider.
        :param _builtins.str oauth_external_client_secret: OAuth token application client secret from external Identity Provider.
        :param _builtins.str oauth_external_token_scope: OAuth client application scope, this is a required field when using Microsoft Azure Entra ID as the identity provider.
        :param _builtins.str oauth_external_token_url: OAuth token URL to fetch access token from external Identity Provider.
        :param _builtins.str oauth_sts_token_expired_in_seconds: OAuth STS access token expired in second from Confluent Cloud
        """
        pulumi.set(__self__, "oauth_identity_pool_id", oauth_identity_pool_id)
        if oauth_external_access_token is not None:
            pulumi.set(__self__, "oauth_external_access_token", oauth_external_access_token)
        if oauth_external_client_id is not None:
            pulumi.set(__self__, "oauth_external_client_id", oauth_external_client_id)
        if oauth_external_client_secret is not None:
            pulumi.set(__self__, "oauth_external_client_secret", oauth_external_client_secret)
        if oauth_external_token_scope is not None:
            pulumi.set(__self__, "oauth_external_token_scope", oauth_external_token_scope)
        if oauth_external_token_url is not None:
            pulumi.set(__self__, "oauth_external_token_url", oauth_external_token_url)
        if oauth_sts_token_expired_in_seconds is not None:
            pulumi.set(__self__, "oauth_sts_token_expired_in_seconds", oauth_sts_token_expired_in_seconds)

    @_builtins.property
    @pulumi.getter(name="oauthIdentityPoolId")
    def oauth_identity_pool_id(self) -> _builtins.str:
        """
        OAuth identity pool id used for processing external token and exchange STS token, registered with Confluent Cloud.
        """
        return pulumi.get(self, "oauth_identity_pool_id")

    @_builtins.property
    @pulumi.getter(name="oauthExternalAccessToken")
    def oauth_external_access_token(self) -> Optional[_builtins.str]:
        """
        OAuth existing static access token already fetched from external Identity Provider.
        """
        return pulumi.get(self, "oauth_external_access_token")

    @_builtins.property
    @pulumi.getter(name="oauthExternalClientId")
    def oauth_external_client_id(self) -> Optional[_builtins.str]:
        """
        OAuth token application client id from external Identity Provider.
        """
        return pulumi.get(self, "oauth_external_client_id")

    @_builtins.property
    @pulumi.getter(name="oauthExternalClientSecret")
    def oauth_external_client_secret(self) -> Optional[_builtins.str]:
        """
        OAuth token application client secret from external Identity Provider.
        """
        return pulumi.get(self, "oauth_external_client_secret")

    @_builtins.property
    @pulumi.getter(name="oauthExternalTokenScope")
    def oauth_external_token_scope(self) -> Optional[_builtins.str]:
        """
        OAuth client application scope, this is a required field when using Microsoft Azure Entra ID as the identity provider.
        """
        return pulumi.get(self, "oauth_external_token_scope")

    @_builtins.property
    @pulumi.getter(name="oauthExternalTokenUrl")
    def oauth_external_token_url(self) -> Optional[_builtins.str]:
        """
        OAuth token URL to fetch access token from external Identity Provider.
        """
        return pulumi.get(self, "oauth_external_token_url")

    @_builtins.property
    @pulumi.getter(name="oauthStsTokenExpiredInSeconds")
    def oauth_sts_token_expired_in_seconds(self) -> Optional[_builtins.str]:
        """
        OAuth STS access token expired in second from Confluent Cloud
        """
        return pulumi.get(self, "oauth_sts_token_expired_in_seconds")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ConnectArtifactArgs', 'ConnectArtifact']

@pulumi.input_type
class ConnectArtifactArgs:
    def __init__(__self__, *,
                 cloud: pulumi.Input[_builtins.str],
                 content_format: pulumi.Input[_builtins.str],
                 display_name: pulumi.Input[_builtins.str],
                 environment: pulumi.Input['ConnectArtifactEnvironmentArgs'],
                 artifact_file: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a ConnectArtifact resource.
        :param pulumi.Input[_builtins.str] cloud: Cloud provider where the Connect Artifact archive is uploaded. Accepted values are: `AWS`, `AZURE`.
        :param pulumi.Input[_builtins.str] content_format: Archive format of the Connect Artifact. Supported formats are `JAR` and `ZIP`.
        :param pulumi.Input[_builtins.str] display_name: The unique name of the Connect Artifact per cloud, environment scope.
        :param pulumi.Input['ConnectArtifactEnvironmentArgs'] environment: Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        :param pulumi.Input[_builtins.str] artifact_file: The artifact file for Connect Artifact in `JAR` or `ZIP` format. This can be relative or absolute path
        :param pulumi.Input[_builtins.str] description: Description of the Connect Artifact.
        """
        pulumi.set(__self__, "cloud", cloud)
        pulumi.set(__self__, "content_format", content_format)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "environment", environment)
        if artifact_file is not None:
            pulumi.set(__self__, "artifact_file", artifact_file)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @_builtins.property
    @pulumi.getter
    def cloud(self) -> pulumi.Input[_builtins.str]:
        """
        Cloud provider where the Connect Artifact archive is uploaded. Accepted values are: `AWS`, `AZURE`.
        """
        return pulumi.get(self, "cloud")

    @cloud.setter
    def cloud(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "cloud", value)

    @_builtins.property
    @pulumi.getter(name="contentFormat")
    def content_format(self) -> pulumi.Input[_builtins.str]:
        """
        Archive format of the Connect Artifact. Supported formats are `JAR` and `ZIP`.
        """
        return pulumi.get(self, "content_format")

    @content_format.setter
    def content_format(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "content_format", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[_builtins.str]:
        """
        The unique name of the Connect Artifact per cloud, environment scope.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter
    def environment(self) -> pulumi.Input['ConnectArtifactEnvironmentArgs']:
        """
        Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: pulumi.Input['ConnectArtifactEnvironmentArgs']):
        pulumi.set(self, "environment", value)

    @_builtins.property
    @pulumi.getter(name="artifactFile")
    def artifact_file(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The artifact file for Connect Artifact in `JAR` or `ZIP` format. This can be relative or absolute path
        """
        return pulumi.get(self, "artifact_file")

    @artifact_file.setter
    def artifact_file(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "artifact_file", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the Connect Artifact.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _ConnectArtifactState:
    def __init__(__self__, *,
                 artifact_file: Optional[pulumi.Input[_builtins.str]] = None,
                 cloud: Optional[pulumi.Input[_builtins.str]] = None,
                 content_format: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 environment: Optional[pulumi.Input['ConnectArtifactEnvironmentArgs']] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ConnectArtifact resources.
        :param pulumi.Input[_builtins.str] artifact_file: The artifact file for Connect Artifact in `JAR` or `ZIP` format. This can be relative or absolute path
        :param pulumi.Input[_builtins.str] cloud: Cloud provider where the Connect Artifact archive is uploaded. Accepted values are: `AWS`, `AZURE`.
        :param pulumi.Input[_builtins.str] content_format: Archive format of the Connect Artifact. Supported formats are `JAR` and `ZIP`.
        :param pulumi.Input[_builtins.str] description: Description of the Connect Artifact.
        :param pulumi.Input[_builtins.str] display_name: The unique name of the Connect Artifact per cloud, environment scope.
        :param pulumi.Input['ConnectArtifactEnvironmentArgs'] environment: Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        :param pulumi.Input[_builtins.str] status: Status of the Connect Artifact.
        """
        if artifact_file is not None:
            pulumi.set(__self__, "artifact_file", artifact_file)
        if cloud is not None:
            pulumi.set(__self__, "cloud", cloud)
        if content_format is not None:
            pulumi.set(__self__, "content_format", content_format)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if environment is not None:
            pulumi.set(__self__, "environment", environment)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="artifactFile")
    def artifact_file(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The artifact file for Connect Artifact in `JAR` or `ZIP` format. This can be relative or absolute path
        """
        return pulumi.get(self, "artifact_file")

    @artifact_file.setter
    def artifact_file(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "artifact_file", value)

    @_builtins.property
    @pulumi.getter
    def cloud(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Cloud provider where the Connect Artifact archive is uploaded. Accepted values are: `AWS`, `AZURE`.
        """
        return pulumi.get(self, "cloud")

    @cloud.setter
    def cloud(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cloud", value)

    @_builtins.property
    @pulumi.getter(name="contentFormat")
    def content_format(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Archive format of the Connect Artifact. Supported formats are `JAR` and `ZIP`.
        """
        return pulumi.get(self, "content_format")

    @content_format.setter
    def content_format(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "content_format", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the Connect Artifact.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique name of the Connect Artifact per cloud, environment scope.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter
    def environment(self) -> Optional[pulumi.Input['ConnectArtifactEnvironmentArgs']]:
        """
        Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: Optional[pulumi.Input['ConnectArtifactEnvironmentArgs']]):
        pulumi.set(self, "environment", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Status of the Connect Artifact.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("confluentcloud:index/connectArtifact:ConnectArtifact")
class ConnectArtifact(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 artifact_file: Optional[pulumi.Input[_builtins.str]] = None,
                 cloud: Optional[pulumi.Input[_builtins.str]] = None,
                 content_format: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 environment: Optional[pulumi.Input[Union['ConnectArtifactEnvironmentArgs', 'ConnectArtifactEnvironmentArgsDict']]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        example = confluentcloud.ConnectArtifact("example",
            display_name="example-connect-artifact",
            cloud="AWS",
            environment={
                "id": "env-123456",
            },
            content_format="JAR",
            artifact_file="path/to/your/artifact.jar",
            description="Example Connect Artifact")
        ```

        ## Import

        You can import a Connect Artifact by using Environment ID, Cloud, and Connect Artifact ID in the format `<Environment ID>/<cloud>/<Connect Artifact ID>`, for example:

        $ export CONFLUENT_CLOUD_API_KEY="<cloud_api_key>"

        $ export CONFLUENT_CLOUD_API_SECRET="<cloud_api_secret>"

        ```sh
        $ pulumi import confluentcloud:index/connectArtifact:ConnectArtifact example env-123456/AWS/ca-123456
        ```

        !> **Warning:** Do not forget to delete terminal command history afterwards for security purposes.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] artifact_file: The artifact file for Connect Artifact in `JAR` or `ZIP` format. This can be relative or absolute path
        :param pulumi.Input[_builtins.str] cloud: Cloud provider where the Connect Artifact archive is uploaded. Accepted values are: `AWS`, `AZURE`.
        :param pulumi.Input[_builtins.str] content_format: Archive format of the Connect Artifact. Supported formats are `JAR` and `ZIP`.
        :param pulumi.Input[_builtins.str] description: Description of the Connect Artifact.
        :param pulumi.Input[_builtins.str] display_name: The unique name of the Connect Artifact per cloud, environment scope.
        :param pulumi.Input[Union['ConnectArtifactEnvironmentArgs', 'ConnectArtifactEnvironmentArgsDict']] environment: Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ConnectArtifactArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        example = confluentcloud.ConnectArtifact("example",
            display_name="example-connect-artifact",
            cloud="AWS",
            environment={
                "id": "env-123456",
            },
            content_format="JAR",
            artifact_file="path/to/your/artifact.jar",
            description="Example Connect Artifact")
        ```

        ## Import

        You can import a Connect Artifact by using Environment ID, Cloud, and Connect Artifact ID in the format `<Environment ID>/<cloud>/<Connect Artifact ID>`, for example:

        $ export CONFLUENT_CLOUD_API_KEY="<cloud_api_key>"

        $ export CONFLUENT_CLOUD_API_SECRET="<cloud_api_secret>"

        ```sh
        $ pulumi import confluentcloud:index/connectArtifact:ConnectArtifact example env-123456/AWS/ca-123456
        ```

        !> **Warning:** Do not forget to delete terminal command history afterwards for security purposes.

        :param str resource_name: The name of the resource.
        :param ConnectArtifactArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ConnectArtifactArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 artifact_file: Optional[pulumi.Input[_builtins.str]] = None,
                 cloud: Optional[pulumi.Input[_builtins.str]] = None,
                 content_format: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 environment: Optional[pulumi.Input[Union['ConnectArtifactEnvironmentArgs', 'ConnectArtifactEnvironmentArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ConnectArtifactArgs.__new__(ConnectArtifactArgs)

            __props__.__dict__["artifact_file"] = artifact_file
            if cloud is None and not opts.urn:
                raise TypeError("Missing required property 'cloud'")
            __props__.__dict__["cloud"] = cloud
            if content_format is None and not opts.urn:
                raise TypeError("Missing required property 'content_format'")
            __props__.__dict__["content_format"] = content_format
            __props__.__dict__["description"] = description
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            if environment is None and not opts.urn:
                raise TypeError("Missing required property 'environment'")
            __props__.__dict__["environment"] = environment
            __props__.__dict__["status"] = None
        super(ConnectArtifact, __self__).__init__(
            'confluentcloud:index/connectArtifact:ConnectArtifact',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            artifact_file: Optional[pulumi.Input[_builtins.str]] = None,
            cloud: Optional[pulumi.Input[_builtins.str]] = None,
            content_format: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            display_name: Optional[pulumi.Input[_builtins.str]] = None,
            environment: Optional[pulumi.Input[Union['ConnectArtifactEnvironmentArgs', 'ConnectArtifactEnvironmentArgsDict']]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None) -> 'ConnectArtifact':
        """
        Get an existing ConnectArtifact resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] artifact_file: The artifact file for Connect Artifact in `JAR` or `ZIP` format. This can be relative or absolute path
        :param pulumi.Input[_builtins.str] cloud: Cloud provider where the Connect Artifact archive is uploaded. Accepted values are: `AWS`, `AZURE`.
        :param pulumi.Input[_builtins.str] content_format: Archive format of the Connect Artifact. Supported formats are `JAR` and `ZIP`.
        :param pulumi.Input[_builtins.str] description: Description of the Connect Artifact.
        :param pulumi.Input[_builtins.str] display_name: The unique name of the Connect Artifact per cloud, environment scope.
        :param pulumi.Input[Union['ConnectArtifactEnvironmentArgs', 'ConnectArtifactEnvironmentArgsDict']] environment: Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        :param pulumi.Input[_builtins.str] status: Status of the Connect Artifact.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ConnectArtifactState.__new__(_ConnectArtifactState)

        __props__.__dict__["artifact_file"] = artifact_file
        __props__.__dict__["cloud"] = cloud
        __props__.__dict__["content_format"] = content_format
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["environment"] = environment
        __props__.__dict__["status"] = status
        return ConnectArtifact(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="artifactFile")
    def artifact_file(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The artifact file for Connect Artifact in `JAR` or `ZIP` format. This can be relative or absolute path
        """
        return pulumi.get(self, "artifact_file")

    @_builtins.property
    @pulumi.getter
    def cloud(self) -> pulumi.Output[_builtins.str]:
        """
        Cloud provider where the Connect Artifact archive is uploaded. Accepted values are: `AWS`, `AZURE`.
        """
        return pulumi.get(self, "cloud")

    @_builtins.property
    @pulumi.getter(name="contentFormat")
    def content_format(self) -> pulumi.Output[_builtins.str]:
        """
        Archive format of the Connect Artifact. Supported formats are `JAR` and `ZIP`.
        """
        return pulumi.get(self, "content_format")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the Connect Artifact.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[_builtins.str]:
        """
        The unique name of the Connect Artifact per cloud, environment scope.
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter
    def environment(self) -> pulumi.Output['outputs.ConnectArtifactEnvironment']:
        """
        Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        """
        return pulumi.get(self, "environment")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        Status of the Connect Artifact.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetTableflowTopicResult',
    'AwaitableGetTableflowTopicResult',
    'get_tableflow_topic',
    'get_tableflow_topic_output',
]

@pulumi.output_type
class GetTableflowTopicResult:
    """
    A collection of values returned by getTableflowTopic.
    """
    def __init__(__self__, azure_data_lake_storage_gen2s=None, byob_aws=None, credentials=None, display_name=None, enable_compaction=None, enable_partitioning=None, environment=None, error_handlings=None, id=None, kafka_cluster=None, managed_storages=None, record_failure_strategy=None, retention_ms=None, suspended=None, table_formats=None, table_path=None, write_mode=None):
        if azure_data_lake_storage_gen2s and not isinstance(azure_data_lake_storage_gen2s, list):
            raise TypeError("Expected argument 'azure_data_lake_storage_gen2s' to be a list")
        pulumi.set(__self__, "azure_data_lake_storage_gen2s", azure_data_lake_storage_gen2s)
        if byob_aws and not isinstance(byob_aws, list):
            raise TypeError("Expected argument 'byob_aws' to be a list")
        pulumi.set(__self__, "byob_aws", byob_aws)
        if credentials and not isinstance(credentials, dict):
            raise TypeError("Expected argument 'credentials' to be a dict")
        pulumi.set(__self__, "credentials", credentials)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if enable_compaction and not isinstance(enable_compaction, bool):
            raise TypeError("Expected argument 'enable_compaction' to be a bool")
        pulumi.set(__self__, "enable_compaction", enable_compaction)
        if enable_partitioning and not isinstance(enable_partitioning, bool):
            raise TypeError("Expected argument 'enable_partitioning' to be a bool")
        pulumi.set(__self__, "enable_partitioning", enable_partitioning)
        if environment and not isinstance(environment, dict):
            raise TypeError("Expected argument 'environment' to be a dict")
        pulumi.set(__self__, "environment", environment)
        if error_handlings and not isinstance(error_handlings, list):
            raise TypeError("Expected argument 'error_handlings' to be a list")
        pulumi.set(__self__, "error_handlings", error_handlings)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if kafka_cluster and not isinstance(kafka_cluster, dict):
            raise TypeError("Expected argument 'kafka_cluster' to be a dict")
        pulumi.set(__self__, "kafka_cluster", kafka_cluster)
        if managed_storages and not isinstance(managed_storages, list):
            raise TypeError("Expected argument 'managed_storages' to be a list")
        pulumi.set(__self__, "managed_storages", managed_storages)
        if record_failure_strategy and not isinstance(record_failure_strategy, str):
            raise TypeError("Expected argument 'record_failure_strategy' to be a str")
        pulumi.set(__self__, "record_failure_strategy", record_failure_strategy)
        if retention_ms and not isinstance(retention_ms, str):
            raise TypeError("Expected argument 'retention_ms' to be a str")
        pulumi.set(__self__, "retention_ms", retention_ms)
        if suspended and not isinstance(suspended, bool):
            raise TypeError("Expected argument 'suspended' to be a bool")
        pulumi.set(__self__, "suspended", suspended)
        if table_formats and not isinstance(table_formats, list):
            raise TypeError("Expected argument 'table_formats' to be a list")
        pulumi.set(__self__, "table_formats", table_formats)
        if table_path and not isinstance(table_path, str):
            raise TypeError("Expected argument 'table_path' to be a str")
        pulumi.set(__self__, "table_path", table_path)
        if write_mode and not isinstance(write_mode, str):
            raise TypeError("Expected argument 'write_mode' to be a str")
        pulumi.set(__self__, "write_mode", write_mode)

    @_builtins.property
    @pulumi.getter(name="azureDataLakeStorageGen2s")
    def azure_data_lake_storage_gen2s(self) -> Sequence['outputs.GetTableflowTopicAzureDataLakeStorageGen2Result']:
        """
        (Optional Configuration Block) supports the following:
        """
        return pulumi.get(self, "azure_data_lake_storage_gen2s")

    @_builtins.property
    @pulumi.getter(name="byobAws")
    def byob_aws(self) -> Sequence['outputs.GetTableflowTopicByobAwResult']:
        """
        (Optional Configuration Block) supports the following:
        """
        return pulumi.get(self, "byob_aws")

    @_builtins.property
    @pulumi.getter
    def credentials(self) -> Optional['outputs.GetTableflowTopicCredentialsResult']:
        return pulumi.get(self, "credentials")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> _builtins.str:
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter(name="enableCompaction")
    def enable_compaction(self) -> _builtins.bool:
        """
        (Optional Boolean) This flag determines whether to enable compaction for the Tableflow enabled topic.
        """
        return pulumi.get(self, "enable_compaction")

    @_builtins.property
    @pulumi.getter(name="enablePartitioning")
    def enable_partitioning(self) -> _builtins.bool:
        """
        (Optional Boolean) This flag determines whether to enable partitioning for the Tableflow enabled topic.
        """
        return pulumi.get(self, "enable_partitioning")

    @_builtins.property
    @pulumi.getter
    def environment(self) -> 'outputs.GetTableflowTopicEnvironmentResult':
        return pulumi.get(self, "environment")

    @_builtins.property
    @pulumi.getter(name="errorHandlings")
    def error_handlings(self) -> Sequence['outputs.GetTableflowTopicErrorHandlingResult']:
        """
        (Optional Configuration Block) supports the following:
        """
        return pulumi.get(self, "error_handlings")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="kafkaCluster")
    def kafka_cluster(self) -> 'outputs.GetTableflowTopicKafkaClusterResult':
        return pulumi.get(self, "kafka_cluster")

    @_builtins.property
    @pulumi.getter(name="managedStorages")
    def managed_storages(self) -> Sequence['outputs.GetTableflowTopicManagedStorageResult']:
        """
        (Optional Configuration Block) The configuration of the Confluent managed bucket.
        """
        return pulumi.get(self, "managed_storages")

    @_builtins.property
    @pulumi.getter(name="recordFailureStrategy")
    def record_failure_strategy(self) -> _builtins.str:
        """
        (Optional String, **Deprecated**) The strategy to handle record failures in the Tableflow enabled topic during materialization. For `SKIP`, we skip the bad records and move to the next record. For `SUSPEND`, we suspend the materialization of the topic.
        """
        return pulumi.get(self, "record_failure_strategy")

    @_builtins.property
    @pulumi.getter(name="retentionMs")
    def retention_ms(self) -> _builtins.str:
        """
        (Optional String) The max age of snapshots (Iceberg) or versions (Delta) (snapshot/version expiration) to keep on the table in milliseconds for the Tableflow enabled topic.
        """
        return pulumi.get(self, "retention_ms")

    @_builtins.property
    @pulumi.getter
    def suspended(self) -> _builtins.bool:
        """
        (Optional Boolean) Indicates whether the Tableflow should be suspended.
        """
        return pulumi.get(self, "suspended")

    @_builtins.property
    @pulumi.getter(name="tableFormats")
    def table_formats(self) -> Sequence[_builtins.str]:
        """
        (Optional List) The supported table formats for the Tableflow-enabled topic.
        """
        return pulumi.get(self, "table_formats")

    @_builtins.property
    @pulumi.getter(name="tablePath")
    def table_path(self) -> _builtins.str:
        """
        (Optional String) The current storage path where the data and metadata is stored for this table.
        """
        return pulumi.get(self, "table_path")

    @_builtins.property
    @pulumi.getter(name="writeMode")
    def write_mode(self) -> _builtins.str:
        """
        (Optional String) Indicates the write mode of the Tableflow topic.
        """
        return pulumi.get(self, "write_mode")


class AwaitableGetTableflowTopicResult(GetTableflowTopicResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTableflowTopicResult(
            azure_data_lake_storage_gen2s=self.azure_data_lake_storage_gen2s,
            byob_aws=self.byob_aws,
            credentials=self.credentials,
            display_name=self.display_name,
            enable_compaction=self.enable_compaction,
            enable_partitioning=self.enable_partitioning,
            environment=self.environment,
            error_handlings=self.error_handlings,
            id=self.id,
            kafka_cluster=self.kafka_cluster,
            managed_storages=self.managed_storages,
            record_failure_strategy=self.record_failure_strategy,
            retention_ms=self.retention_ms,
            suspended=self.suspended,
            table_formats=self.table_formats,
            table_path=self.table_path,
            write_mode=self.write_mode)


def get_tableflow_topic(credentials: Optional[Union['GetTableflowTopicCredentialsArgs', 'GetTableflowTopicCredentialsArgsDict']] = None,
                        display_name: Optional[_builtins.str] = None,
                        environment: Optional[Union['GetTableflowTopicEnvironmentArgs', 'GetTableflowTopicEnvironmentArgsDict']] = None,
                        kafka_cluster: Optional[Union['GetTableflowTopicKafkaClusterArgs', 'GetTableflowTopicKafkaClusterArgsDict']] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTableflowTopicResult:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `TableflowTopic` describes a Tableflow Topic data source.

    ## Example Usage

    ### Option #1: Manage multiple Tableflow Topics in the same Pulumi Stack

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    example = confluentcloud.get_tableflow_topic(environment={
            "id": staging["id"],
        },
        kafka_cluster={
            "id": staging_confluent_kafka_cluster["id"],
        },
        display_name="tableflow-example",
        credentials={
            "key": env_admin_tableflow_api_key["id"],
            "secret": env_admin_tableflow_api_key["secret"],
        })
    pulumi.export("retention-ms", example.retention_ms)
    ```

    ### Option #2: Manage a single Tableflow Topic in the same Pulumi Stack

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    example = confluentcloud.get_tableflow_topic(display_name="tableflow-example")
    pulumi.export("retention-ms", example.retention_ms)
    ```


    :param _builtins.str display_name: The name of the Tableflow Topic.
    """
    __args__ = dict()
    __args__['credentials'] = credentials
    __args__['displayName'] = display_name
    __args__['environment'] = environment
    __args__['kafkaCluster'] = kafka_cluster
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('confluentcloud:index/getTableflowTopic:getTableflowTopic', __args__, opts=opts, typ=GetTableflowTopicResult).value

    return AwaitableGetTableflowTopicResult(
        azure_data_lake_storage_gen2s=pulumi.get(__ret__, 'azure_data_lake_storage_gen2s'),
        byob_aws=pulumi.get(__ret__, 'byob_aws'),
        credentials=pulumi.get(__ret__, 'credentials'),
        display_name=pulumi.get(__ret__, 'display_name'),
        enable_compaction=pulumi.get(__ret__, 'enable_compaction'),
        enable_partitioning=pulumi.get(__ret__, 'enable_partitioning'),
        environment=pulumi.get(__ret__, 'environment'),
        error_handlings=pulumi.get(__ret__, 'error_handlings'),
        id=pulumi.get(__ret__, 'id'),
        kafka_cluster=pulumi.get(__ret__, 'kafka_cluster'),
        managed_storages=pulumi.get(__ret__, 'managed_storages'),
        record_failure_strategy=pulumi.get(__ret__, 'record_failure_strategy'),
        retention_ms=pulumi.get(__ret__, 'retention_ms'),
        suspended=pulumi.get(__ret__, 'suspended'),
        table_formats=pulumi.get(__ret__, 'table_formats'),
        table_path=pulumi.get(__ret__, 'table_path'),
        write_mode=pulumi.get(__ret__, 'write_mode'))
def get_tableflow_topic_output(credentials: Optional[pulumi.Input[Optional[Union['GetTableflowTopicCredentialsArgs', 'GetTableflowTopicCredentialsArgsDict']]]] = None,
                               display_name: Optional[pulumi.Input[_builtins.str]] = None,
                               environment: Optional[pulumi.Input[Union['GetTableflowTopicEnvironmentArgs', 'GetTableflowTopicEnvironmentArgsDict']]] = None,
                               kafka_cluster: Optional[pulumi.Input[Union['GetTableflowTopicKafkaClusterArgs', 'GetTableflowTopicKafkaClusterArgsDict']]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetTableflowTopicResult]:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `TableflowTopic` describes a Tableflow Topic data source.

    ## Example Usage

    ### Option #1: Manage multiple Tableflow Topics in the same Pulumi Stack

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    example = confluentcloud.get_tableflow_topic(environment={
            "id": staging["id"],
        },
        kafka_cluster={
            "id": staging_confluent_kafka_cluster["id"],
        },
        display_name="tableflow-example",
        credentials={
            "key": env_admin_tableflow_api_key["id"],
            "secret": env_admin_tableflow_api_key["secret"],
        })
    pulumi.export("retention-ms", example.retention_ms)
    ```

    ### Option #2: Manage a single Tableflow Topic in the same Pulumi Stack

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    example = confluentcloud.get_tableflow_topic(display_name="tableflow-example")
    pulumi.export("retention-ms", example.retention_ms)
    ```


    :param _builtins.str display_name: The name of the Tableflow Topic.
    """
    __args__ = dict()
    __args__['credentials'] = credentials
    __args__['displayName'] = display_name
    __args__['environment'] = environment
    __args__['kafkaCluster'] = kafka_cluster
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('confluentcloud:index/getTableflowTopic:getTableflowTopic', __args__, opts=opts, typ=GetTableflowTopicResult)
    return __ret__.apply(lambda __response__: GetTableflowTopicResult(
        azure_data_lake_storage_gen2s=pulumi.get(__response__, 'azure_data_lake_storage_gen2s'),
        byob_aws=pulumi.get(__response__, 'byob_aws'),
        credentials=pulumi.get(__response__, 'credentials'),
        display_name=pulumi.get(__response__, 'display_name'),
        enable_compaction=pulumi.get(__response__, 'enable_compaction'),
        enable_partitioning=pulumi.get(__response__, 'enable_partitioning'),
        environment=pulumi.get(__response__, 'environment'),
        error_handlings=pulumi.get(__response__, 'error_handlings'),
        id=pulumi.get(__response__, 'id'),
        kafka_cluster=pulumi.get(__response__, 'kafka_cluster'),
        managed_storages=pulumi.get(__response__, 'managed_storages'),
        record_failure_strategy=pulumi.get(__response__, 'record_failure_strategy'),
        retention_ms=pulumi.get(__response__, 'retention_ms'),
        suspended=pulumi.get(__response__, 'suspended'),
        table_formats=pulumi.get(__response__, 'table_formats'),
        table_path=pulumi.get(__response__, 'table_path'),
        write_mode=pulumi.get(__response__, 'write_mode')))
